/* cbs_normalize.cpp
 *
 * Mex entry point for the function normalizing values.
 * See cbs_normalize.m for documentation.
 *
 * History
 *  2011/06/24: First version
 *
 * Note
 *  CBS is partly based on the original source code of BBS.
 *
 * (c)2011, Florent Brunet.
 */
 
/* This file is part of CBS.
 *
 * CBS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * CBS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CBS.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "mex.h"
#include "cbs_mex.h"


void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]) {
    double tmin, tmax;
    int npts;
    double *t = NULL, *nt = NULL;
    int *inter = NULL;
    int nb_t;
    mwSize ndim_t;
    const mwSize *dim_t;
    
    if (nrhs != 4) 
        mexErrMsgTxt("Four inputs required.");
    
    if (nlhs < 1 || nlhs > 2) 
        mexErrMsgTxt("One or two outputs required.");
    
    check_real_scalar(prhs[0], "tmin");
    check_real_scalar(prhs[1], "tmax");
    check_real_scalar(prhs[2], "npts");
    
    tmin = mxGetScalar(prhs[0]);
    tmax = mxGetScalar(prhs[1]);
    npts = (int)mxGetScalar(prhs[2]);
    t = mxGetPr(prhs[3]);
    nb_t = mxGetNumberOfElements(prhs[3]);
    ndim_t = mxGetNumberOfDimensions(prhs[3]);
    dim_t = mxGetDimensions(prhs[3]);
    
    plhs[0] = mxCreateNumericArray(ndim_t, dim_t, mxDOUBLE_CLASS, mxREAL);
    nt = mxGetPr(plhs[0]);
    
    if (nlhs == 2) {
        plhs[1] = mxCreateNumericArray(ndim_t, dim_t, mxINT32_CLASS, mxREAL);
        inter = (int*)mxGetData(plhs[1]);
        normalize_with_inter(tmin, tmax, npts, t, nb_t, nt, inter);
    } else
        normalize(tmin, tmax, npts, t, nb_t, nt);
}
